@@ -208,23 +208,49 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 		return OK;
 
 	case SETBOOKMARK_A:
-		if (c < 0) c = 0;
-		if (c < NUM_BOOKMARKS) {
+	case UNSETBOOKMARK_A:
+	case GOTOBOOKMARK_A:
+		/* *p can be  "", "-", "0".."9", for which, respectively, */
+		/*  c becomes  1,  0,   1 .. 10. Anything else is out of range. */
+		if (p) {
+			if (p[0]) {
+				if (!p[1]) {
+					if (*p == '-') c = 0;
+					else c = *p - '0' + 1;
+				}
+				else c = -1;
+			}
+			else c = 1;
+			free(p);
+			if (c < 0 || c >= NUM_BOOKMARKS) return BOOKMARK_OUT_OF_RANGE;
+		}
+		else 
+			c = 1;
+		switch(a) {
+		case SETBOOKMARK_A:
 			b->bookmark[c].pos = b->cur_pos;
 			b->bookmark[c].line = b->cur_line;
-			return OK;
+			b->bookmark_mask |= (1 << c);
+			break;
+		case UNSETBOOKMARK_A:
+			if (! (b->bookmark_mask & (1 << c)))
+				return BOOKMARK_NOT_SET;
+			b->bookmark_mask &= ~(1 << c);
+			break;
+		case GOTOBOOKMARK_A:
+			if (! (b->bookmark_mask & (1 << c))) return BOOKMARK_NOT_SET;
+			{
+				const int prev_line = b->cur_line;
+				const int prev_pos  = b->cur_pos;
+				delay_update();
+				goto_line(b, b->bookmark[c].line);
+				goto_pos(b, b->bookmark[c].pos);
+				b->bookmark[0].line = prev_line;
+				b->bookmark[0].pos = prev_pos;
+				b->bookmark_mask |= 1;
+			}
 		}
-		return BOOKMARK_OUT_OF_RANGE;
-
-	case GOTOBOOKMARK_A:
-		if (c < 0) c = 0;
-		if (c < NUM_BOOKMARKS) {
-			delay_update();
-			goto_line(b, b->bookmark[c].line);
-			goto_pos(b, b->bookmark[c].pos);
-			return OK;
-		}
-		return BOOKMARK_OUT_OF_RANGE;
+		return OK;
 
 	case GOTOLINE_A:
 		if (c < 0 && (c = request_number("Line", b->cur_line + 1))<0) return NUMERIC_ERROR(c);
@@ -805,8 +831,8 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 		i = b->recording;
 		SET_USER_FLAG(b, c, recording);
 		if (b->recording && !i) {
-		   b->cur_macro = reset_stream(b->cur_macro);
-		   print_message(info_msg[STARTING_MACRO_RECORDING]);
+			b->cur_macro = reset_stream(b->cur_macro);
+			print_message(info_msg[STARTING_MACRO_RECORDING]);
 		}
 		else if (!b->recording && i) print_message(info_msg[MACRO_RECORDING_COMPLETED]);
 		return OK;
@@ -825,7 +851,7 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 		if (p || (p = request_file(b, "Macro Name", NULL))) {
 			print_info(SAVING);
 			optimize_macro( b->cur_macro, b->opt.verbose_macros );
-			if ((error = print_error(save_stream(b->cur_macro, p, b->is_CRLF))) == OK) print_info(SAVED);
+			if ((error = print_error(save_stream(b->cur_macro, p, b->is_CRLF, FALSE))) == OK) print_info(SAVED);
 			free(p);
 			return error ? ERROR : 0;
 		}
@@ -834,7 +860,7 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 	case OPENMACRO_A:
 		if (p || (p = request_file(b, "Macro Name", NULL))) {
 			char_stream *cs;
-			cs = load_stream(b->cur_macro, p, FALSE);
+			cs = load_stream(b->cur_macro, p, FALSE, FALSE);
 			if (cs) b->cur_macro = cs;
 			free(p);
 			return cs ? 0 : ERROR;
@@ -950,7 +976,7 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 
 	case OPENCLIP_A:
 		if (p || (p = request_file(b, "Clip Name", NULL))) {
-			error = print_error(load_clip(b->opt.cur_clip, p, b->opt.preserve_cr));
+			error = print_error(load_clip(b->opt.cur_clip, p, b->opt.preserve_cr, b->opt.binary));
 			free(p);
 			return error ? ERROR : 0;
 		}
@@ -959,7 +985,7 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 	case SAVECLIP_A:
 		if (p || (p = request_file(b, "Clip Name", NULL))) {
 			print_info(SAVING);
-			if ((error = print_error(save_clip(b->opt.cur_clip, p, b->is_CRLF))) == OK) print_info(SAVED);
+			if ((error = print_error(save_clip(b->opt.cur_clip, p, b->is_CRLF, b->opt.binary))) == OK) print_info(SAVED);
 			free(p);
 			return error ? ERROR : 0;
 		}
@@ -1005,7 +1031,7 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 
 			if (!b->marking || !(error = (b->mark_is_vertical ? copy_vert_to_clip : copy_to_clip)(b, INT_MAX, FALSE))) {
 
-				if (!(error = save_clip(INT_MAX, tmpnam1, b->is_CRLF))) {
+				if (!(error = save_clip(INT_MAX, tmpnam1, b->is_CRLF, b->opt.binary))) {
 					if (command = malloc(strlen(p) + strlen(tmpnam1) + strlen(tmpnam2) + 16)) {
 
 						strcat(strcat(strcat(strcat(strcpy(command, p), " <"), tmpnam1), " >"), tmpnam2);
@@ -1016,7 +1042,7 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 							
 						if (!error) {
 
-							if (!(error = load_clip(INT_MAX, tmpnam2, b->opt.preserve_cr))) {
+							if (!(error = load_clip(INT_MAX, tmpnam2, b->opt.preserve_cr, b->opt.binary))) {
 
 								start_undo_chain(b);
 
