@@ -246,7 +246,8 @@ void free_buffer_contents(buffer * const b) {
 	b->allocated_chars = b->free_chars = 0;
 	b->is_CRLF = FALSE;
 	b->encoding = ENC_ASCII;
-
+	b->bookmark_mask = 0;
+        
 	free_char_stream(b->last_deleted);
 	b->last_deleted = NULL;
 
@@ -718,8 +719,10 @@ int delete_one_line(buffer * const b, line_desc * const ld, const int line) {
 int undelete_line(buffer * const b) {
 
 	if (!b->last_deleted) return ERROR;
+	start_undo_chain(b);
 	insert_one_line(b, b->cur_line_desc, b->cur_line, b->cur_pos);
 	insert_stream(b, b->cur_line_desc, b->cur_line, b->cur_pos, b->last_deleted->stream, b->last_deleted->len);
+	end_undo_chain(b);
 	return OK;
 }
 
@@ -741,9 +744,9 @@ void delete_to_eol(buffer * const b, line_desc * const ld, const int line, const
 	record the inverse operation in the undo buffer if b->opt.do_undo is
 	TRUE. */
 
-int insert_stream(buffer * const b, line_desc * ld, const int line, int pos, const unsigned char * const stream, const int stream_len) {
+int insert_stream(buffer * const b, line_desc * ld, int line, int pos, const unsigned char * const stream, const int stream_len) {
 
-	int i, len;
+	int i, len, mask;
 	unsigned char *p;
 	const unsigned char *s = stream;
 
@@ -764,7 +767,7 @@ int insert_stream(buffer * const b, line_desc * ld, const int line, int pos, con
 
 	while(s - stream < stream_len) {
 
-		if (len = strnlen(s, stream_len - (s - stream))) {
+		if (len = strnlen_ne(s, stream_len - (s - stream))) {
 
 			/* First case; there is no character allocated on this line. We
 			have to freshly allocate the line. */
@@ -813,6 +816,12 @@ int insert_stream(buffer * const b, line_desc * ld, const int line, int pos, con
 				ld->line_len += len;
 			}
 			b->is_modified = 1;
+			
+			/* We just inserted len chars at (line,pos); adjust bookmarks and mark accordingly. */
+			if (b->marking && b->block_start_line == line && b->block_start_col > pos ) b->block_start_col += len;
+
+			for (i=0, mask=b->bookmark_mask;  mask;  i++, mask >>= 1) 
+				if ((mask & 1) && b->bookmark[i].line == line && b->bookmark[i].pos > pos ) b->bookmark[i].pos += len;
 		}
 
 		/* If the string we have inserted has a NULL at the end, we create a new
@@ -835,7 +844,27 @@ int insert_stream(buffer * const b, line_desc * ld, const int line, int pos, con
 
 				b->is_modified = 1;
 				ld = new_ld;
+				
+				/* We just inserted a line break at (line,pos);
+				   adjust the buffer bookmarks and mark accordingly. */
+				if (b->marking) {
+					if (b->block_start_line == line && b->block_start_col > pos ) {
+						b->block_start_col -= pos;
+						b->block_start_line++;
+					}
+					else if ( b->block_start_line > line ) b->block_start_line++;
+				}
+				for (i=0, mask=b->bookmark_mask;  mask;  i++, mask >>= 1) {
+					if (mask & 1) {
+						if (b->bookmark[i].line == line && b->bookmark[i].pos > pos ) {
+							b->bookmark[i].pos -= pos;
+							b->bookmark[i].line++;
+						}
+						else if (b->bookmark[i].line > line ) b->bookmark[i].line++;
+					}
+				}
 				pos = 0;
+				line++;
 			}
 			else {
 				release_signals();
@@ -900,7 +929,7 @@ int insert_spaces(buffer * const b, line_desc * const ld, const int line, const
 
 int delete_stream(buffer * const b, line_desc * const ld, const int line, const int pos, int len) {
 
-	int n, m;
+	int n, m, mask;
 
 	assert_buffer(b);
 	assert_line_desc(ld, b->encoding);
@@ -931,6 +960,24 @@ int delete_stream(buffer * const b, line_desc * const ld, const int line, const
 			assert(next_ld != NULL);
 			assert_line_desc(next_ld, b->encoding);
 
+			/* We're about to join line+1 to line; adjust mark and bookmarks accordingly. */
+			if (b->marking) {
+				if (b->block_start_line == line+1) {
+					b->block_start_line--;
+					b->block_start_col += ld->line_len;
+				}
+				else if (b->block_start_line > line ) b->block_start_line--;
+			}
+			for (n=0, mask=b->bookmark_mask;  mask;  n++, mask >>= 1) {
+				if (mask & 1) {
+					if (b->bookmark[n].line == line+1) {
+						b->bookmark[n].line--;
+						b->bookmark[n].pos += ld->line_len;
+					}
+					else if (b->bookmark[n].line > line ) b->bookmark[n].line--;
+				}
+			}
+			
 			/* If one of the lines is empty, or their contents are adjacent,
 			we simply set a pointer. */
 
@@ -999,6 +1046,23 @@ int delete_stream(buffer * const b, line_desc * const ld, const int line, const
 
 		else {
 			n = len > ld->line_len - pos ? ld->line_len - pos : len;
+			
+			/* We're about to erase n chars at (line,pos); adjust mark and bookmarks accordingly. */
+			if (b->marking)
+				if (b->block_start_line == line )
+					if ( b->block_start_col >= pos )
+						if (b->block_start_col < pos + n )
+							b->block_start_col = pos;
+						else
+							b->block_start_col -= n;
+			for (m=0, mask=b->bookmark_mask;  mask;  m++, mask>>=1) {
+				if (mask & 1) {
+					if (b->bookmark[m].line == line )
+						if ( b->bookmark[m].pos >= pos )
+							if (b->bookmark[m].pos < pos + n ) b->bookmark[m].pos = pos;
+							else b->bookmark[m].pos -= n;
+				}
+			}
 
 			if (!b->redoing) {
 				if (b->undoing) add_to_stream(&b->undo.redo, &ld->line[pos], n);
