@@ -318,8 +318,16 @@ int paste_to_buffer(buffer *b, int n) {
 
 	if (!cd->cs->len) return OK;
 	if (cd->cs->encoding == ENC_ASCII || b->encoding == ENC_ASCII || cd->cs->encoding == b->encoding) {
+		line_desc * const ld = b->cur_line_desc;
 		if (b->encoding == ENC_ASCII) b->encoding = cd->cs->encoding;
+
+		start_undo_chain(b);
+		if (b->cur_pos > ld->line_len) 
+			insert_spaces(b, ld, b->cur_line, ld->line_len, b->win_x + b->cur_x - calc_width(ld, ld->line_len, b->opt.tab_size, b->encoding));
+
 		insert_stream(b, b->cur_line_desc, b->cur_line, b->cur_pos, cd->cs->stream, cd->cs->len);
+		end_undo_chain(b);
+
 		return OK;
 	}
 
@@ -532,7 +540,7 @@ int paste_vert_to_buffer(buffer *b, int n) {
 				ld = (line_desc *)ld->ld_node.prev;
 		}
 
-		if (len = strnlen(p, stream_len - (p - stream))) {
+		if (len = strnlen_ne(p, stream_len - (p - stream))) {
 			for(n = i=0; i < ld->line_len && n < x; i = next_pos(ld->line, i, b->encoding)) {
 				if (ld->line[i] == '\t') n += b->opt.tab_size - n % b->opt.tab_size;
 				else n += get_char_width(&ld->line[i], b->encoding);
@@ -560,7 +568,7 @@ int paste_vert_to_buffer(buffer *b, int n) {
 /* Loads a clip. It is just a load_stream, plus an insertion in the clip
 	list. If preserve_cr is TRUE, CRs are preserved. */
 
-int load_clip(int n, const char *name, int preserve_cr) {
+int load_clip(int n, const char *name, const int preserve_cr, const int binary) {
 	int error;
 
 	clip_desc *cd = get_nth_clip(n);
@@ -570,7 +578,7 @@ int load_clip(int n, const char *name, int preserve_cr) {
 		add_head(&clips, &cd->cd_node);
 	}
 
-	error = load_stream(cd->cs, name, preserve_cr) ? OK : CANT_OPEN_FILE;
+	error = load_stream(cd->cs, name, preserve_cr, binary) ? OK : CANT_OPEN_FILE;
 
 	if (error == OK) set_stream_encoding(cd->cs, ENC_ASCII);
 
@@ -581,10 +589,10 @@ int load_clip(int n, const char *name, int preserve_cr) {
 /* Saves a clip to a file. If CRLF is true, the clip is saved with CR/LF pairs
  as line terminators. */
 
-int save_clip(int n, const char *name, int CRLF) {
+int save_clip(int n, const char *name, const int CRLF, const int binary) {
 
 	clip_desc *cd = get_nth_clip(n);
 
 	if (!cd) return CLIP_DOESNT_EXIST;
-	return save_stream(cd->cs, name, CRLF);
+	return save_stream(cd->cs, name, CRLF, binary);
 }
