@@ -97,7 +97,7 @@ static const command commands[ACTION_COUNT] = {
 	{ NAHL(FLAGS         ), NO_ARGS |                             DO_NOT_RECORD                   },
 	{ NAHL(FLASH         ), NO_ARGS                                                               },
 	{ NAHL(FREEFORM      ),                           IS_OPTION                                   },
-	{ NAHL(GOTOBOOKMARK  ),0                                                                      },
+	{ NAHL(GOTOBOOKMARK  ),           ARG_IS_STRING |                             EMPTY_STRING_OK },
 	{ NAHL(GOTOCOLUMN    ),0                                                                      },
 	{ NAHL(GOTOLINE      ),0                                                                      },
 	{ NAHL(GOTOMARK      ), NO_ARGS                                                               },
@@ -168,7 +168,7 @@ static const command commands[ACTION_COUNT] = {
 	{ NAHL(SAVEPREFS     ),           ARG_IS_STRING                                               },
 	{ NAHL(SEARCHBACK    ),                           IS_OPTION                                   },
 	{ NAHL(SELECTDOC     ),0                                                                      },
-	{ NAHL(SETBOOKMARK   ),0                                                                      },
+	{ NAHL(SETBOOKMARK   ),           ARG_IS_STRING |                             EMPTY_STRING_OK },
 	{ NAHL(STATUSBAR     ),                           IS_OPTION                                   },
 	{ NAHL(SUSPEND       ), NO_ARGS                                                               },
 	{ NAHL(SYSTEM        ),           ARG_IS_STRING                                               },
@@ -182,6 +182,7 @@ static const command commands[ACTION_COUNT] = {
 	{ NAHL(UNDELLINE     ),0                                                                      },
 	{ NAHL(UNDO          ),0                                                                      },
 	{ NAHL(UNLOADMACROS  ), NO_ARGS                                                               },
+	{ NAHL(UNSETBOOKMARK ),           ARG_IS_STRING |                             EMPTY_STRING_OK },
 	{ NAHL(UTF8          ),                           IS_OPTION                                   },
 	{ NAHL(UTF8AUTO      ),                           IS_OPTION                                   },
 	{ NAHL(UTF8IO        ),                           IS_OPTION                                   },
@@ -199,7 +200,7 @@ int cmdcmp(const unsigned char *c, const unsigned char *m) {
 	assert(c != NULL);
 	assert(m != NULL);
 
-	while (*c && up_case[*c] == up_case[*m]) {
+	while (*c && ascii_up_case[*c] == ascii_up_case[*m]) {
 		c++;
 		m++;
 	}
@@ -229,7 +230,7 @@ static macro_desc *macro_hash_table[MACRO_HASH_TABLE_SIZE];
 static int hash(const unsigned char * const s, int len) {
 	int h = -1;
 
-	while(len-- != 0) h = (h * 31 + up_case[s[len]]) % HASH_TABLE_SIZE;
+	while(len-- != 0) h = (h * 31 + ascii_up_case[s[len]]) % HASH_TABLE_SIZE;
 	return ( h + HASH_TABLE_SIZE ) % HASH_TABLE_SIZE;
 }
 
@@ -237,7 +238,7 @@ static int hash(const unsigned char * const s, int len) {
 static int hash_macro(const unsigned char * const s, int len) {
 	int h = -1;
 
-	while(len-- != 0) h = (h * 31 + up_case[s[len]]) % MACRO_HASH_TABLE_SIZE;
+	while(len-- != 0) h = (h * 31 + ascii_up_case[s[len]]) % MACRO_HASH_TABLE_SIZE;
 	return ( h + MACRO_HASH_TABLE_SIZE ) % MACRO_HASH_TABLE_SIZE;
 }
 
@@ -539,17 +540,17 @@ macro_desc *load_macro(const char *name) {
 
 	if (!(md = alloc_macro_desc())) return NULL;
 
-	cs = load_stream(md->cs, name, FALSE);
+	cs = load_stream(md->cs, name, FALSE, FALSE);
 
 	if (!cs && (prefs_dir = exists_prefs_dir()) && (macro_dir = malloc(strlen(prefs_dir) + 2 + strlen(name)))) {
 		strcat(strcpy(macro_dir, prefs_dir), name);
-		cs = load_stream(md->cs, macro_dir, FALSE);
+		cs = load_stream(md->cs, macro_dir, FALSE, FALSE);
 		free(macro_dir);
 	}
 
 	if (!cs && (prefs_dir = exists_gprefs_dir()) && (macro_dir = malloc(strlen(prefs_dir) + 2 + strlen(name)))) {
 		strcat(strcpy(macro_dir, prefs_dir), name);
-		cs = load_stream(md->cs, macro_dir, FALSE);
+		cs = load_stream(md->cs, macro_dir, FALSE, FALSE);
 		free(macro_dir);
 	}
 
