@@ -1,7 +1,7 @@
 /* Definition for debug statements and assertions.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2001 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -25,7 +25,7 @@
 
 void __assert(int x, char *expr, char *file, int line);
 
-#define assert(x)  __assert((x), #x, __FILE__, __LINE__)
+#define assert(x) { __assert((x), #x, __FILE__, __LINE__); if(!(x)) abort();}
 
 #else
 
