@@ -28,8 +28,6 @@
 
 #define NUM_BRACKETS 4
 
-
-
 /* Applies a given to_first() function to the first letter of the starting at the cursor, and to_rest() to
 	the following alphabetical letter (see the functions below). */
 
@@ -45,14 +43,14 @@ static int to_something(buffer *b, int (to_first)(int), int (to_rest)(int)) {
 	if (b->cur_line == b->num_lines -1 && b->cur_pos >= b->cur_line_desc->line_len) return ERROR;
 
 	/* First of all, we search for the word start, if we're not over it. */
-	if (pos >= b->cur_line_desc->line_len || utf8ispunct(c = get_char(&b->cur_line_desc->line[pos], b->encoding)) || utf8isspace(c)) search_word(b, 1);
+	if (pos >= b->cur_line_desc->line_len || ne_ispunct(c = get_char(&b->cur_line_desc->line[pos], b->encoding), b->encoding) || ne_isspace(c, b->encoding)) search_word(b, 1);
 	x = b->cur_x; /* The original x position (to perform the line update). */
 
 	pos = b->cur_pos;
 	new_len = 0;
 	/* Then, we compute the word position extremes, length of the result (which
 		may change because of casing). */
-	while (pos < b->cur_line_desc->line_len && !(utf8ispunct(c = get_char(&b->cur_line_desc->line[pos], b->encoding)) || utf8isspace(c))) {
+	while (pos < b->cur_line_desc->line_len && !(ne_ispunct(c = get_char(&b->cur_line_desc->line[pos], b->encoding), b->encoding) || ne_isspace(c, b->encoding))) {
 		new_c = new_len ? to_rest(c) : to_first(c);
 		changed |= (c != new_c);
 
@@ -75,7 +73,7 @@ static int to_something(buffer *b, int (to_first)(int), int (to_rest)(int)) {
 		pos = b->cur_pos;
 		new_len = 0;
 		/* Second pass: we actually build the transformed word. */
-		while (pos < b->cur_line_desc->line_len && !(utf8ispunct(c = get_char(&b->cur_line_desc->line[pos], b->encoding)) || utf8isspace(c))) {
+		while (pos < b->cur_line_desc->line_len && !(ne_ispunct(c = get_char(&b->cur_line_desc->line[pos], b->encoding), b->encoding) || ne_isspace(c, b->encoding))) {
 			if (b->encoding == ENC_UTF8) new_len += utf8str(new_len ? to_rest(c) : to_first(c), word + new_len);
 			else {
 				word[new_len] = new_len ? to_rest(c) : to_first(c);
@@ -206,15 +204,15 @@ int word_wrap(buffer * const b) {
 	first_pos = 0;
 
 	/* Skip leading white space */
-	while (first_pos < len && utf8isspace(get_char(&line[first_pos], b->encoding))) first_pos = next_pos(line, first_pos, b->encoding);
+	while (first_pos < len && ne_isspace(get_char(&line[first_pos], b->encoding), b->encoding)) first_pos = next_pos(line, first_pos, b->encoding);
 
 	/* Skip non_space after leading white space */
-	while (first_pos < len && !utf8isspace(get_char(&line[first_pos], b->encoding))) first_pos = next_pos(line, first_pos, b->encoding);
+	while (first_pos < len && !ne_isspace(get_char(&line[first_pos], b->encoding), b->encoding)) first_pos = next_pos(line, first_pos, b->encoding);
 	
 	/* Now we know that the line shouldn't be broken before &line[first_pos]. */
 	
    /* Start from the other end now and find a candidate space to break the line on.*/
-	while((pos = prev_pos(line, pos, b->encoding)) && !utf8isspace(get_char(&line[pos], b->encoding)));
+	while((pos = prev_pos(line, pos, b->encoding)) && !ne_isspace(get_char(&line[pos], b->encoding), b->encoding));
 
 	if (! pos || pos < first_pos) return ERROR;
 
@@ -575,7 +573,7 @@ int auto_indent_line(buffer * const b) {
 
 	if (ld->line_len == 0) return 0;
 
-	while(pos < ld->line_len && utf8isspace(get_char(&ld->line[pos], b->encoding))) pos = next_pos(ld->line, pos, b->encoding);
+	while(pos < ld->line_len && ne_isspace(get_char(&ld->line[pos], b->encoding), b->encoding)) pos = next_pos(ld->line, pos, b->encoding);
 	insert_stream(b, b->cur_line_desc, b->cur_line, 0, ld->line, pos);
 	return pos;
 }
