@@ -1,7 +1,7 @@
 /* List handling functions.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2001 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -23,14 +23,15 @@
 
 #include "ne.h"
 
-/* These functions provide basic management of lists. The basic ideas in this file come
-from the Amiga Exec list management functions and their C counterparts developed by
-Marco Zandonadi. Note that because of the way a list is defined, there are never
-special cases for the empty list. The price to pay is that a list is empty not
-if it's NULL, but rather is l->head->next is NULL. The first node of a list is l->head,
-the last one is l->tail_pred. A node is the last in a list if n->next->next == NULL. */
+/* These functions provide basic management of lists. The basic ideas in this
+   file come from the Amiga Exec list management functions and their C
+   counterparts developed by Marco Zandonadi. Note that because of the way a
+   list is defined, there are never special cases for the empty list. The price
+   to pay is that a list is empty not if it's NULL, but rather is l->head->next
+   is NULL. The first node of a list is l->head, the last one is
+   l->tail_pred. A node is the last in a list if n->next->next == NULL. */
 
-/* This function initializes a list before any usage. */
+/* Initializes a list before any usage. */
 
 void new_list(list *l) {
 	l->head = (node *)&(l->tail);
@@ -39,7 +40,7 @@ void new_list(list *l) {
 }
 
 
-/* This function inserts a node at the head of a list. */
+/* Inserts a node at the head of a list. */
 
 void add_head(list *l, node *n) {
 	n->next = l->head;
@@ -50,7 +51,7 @@ void add_head(list *l, node *n) {
 }
 
 
-/* This function inserts a node at the tail of a list. */
+/* Inserts a node at the tail of a list. */
 
 void add_tail(list *l, node *n) {
 	n->next = (node *)&l->tail;
@@ -61,8 +62,7 @@ void add_tail(list *l, node *n) {
 }
 
 
-/* This function removes a node. Note that we do *not* need to know the
-list. */
+/* Removes a node. Note that we do *not* need to know the list. */
 
 void rem(node *n) {
 	n->prev->next = n->next;
@@ -70,8 +70,8 @@ void rem(node *n) {
 }
 
 
-/* This function adds a node to a list after a specified position. list.head
-and list.tail_pred are valid positions. */
+/* Adds a node to a list after a specified position. list.head and
+   list.tail_pred are valid positions. */
 
 void add(node *n, node *pos) {
 	n->next = pos->next;
@@ -81,8 +81,8 @@ void add(node *n, node *pos) {
 }
 
 
-/* This function applies a given deallocation function throughout a whole
-list, emptying the list itself. */
+/* Applies a given deallocation function throughout a whole list, emptying the
+   list itself. */
 
 void free_list(list *l, void (func)()) {
 
@@ -96,7 +96,7 @@ void free_list(list *l, void (func)()) {
 	}
 }
 
-/* This function applies a given function throughout a whole list. */
+/* Applies a given function throughout a whole list. */
 
 void apply_to_list(list *l, void (func)()) {
 	node *n1 = l->head;
