@@ -69,8 +69,8 @@ const char * const AUTOINDENT_HELP[22] = {
   "action in the undo buffer (with respect to the line creation). If you",
   "are not satisfied with the indentation, just give the `Undo' command and",
   "the indentation will disappear (but the new line will remain in place,",
-  "since its creation has been recorded as a separate action). See",
-  "Undo.",
+  "since its creation has been recorded as a separate action). See ",
+  "`Undo'.",
 };
 
 const char * const AUTOPREFS_HELP[14] = {
@@ -134,7 +134,7 @@ const char * const CAPITALIZE_HELP[6] = {
   "Abbreviation: CA",
   "",
   "acts exactly like `ToUpper', but capitalizes, that is, makes the first",
-  "letter upper case and the other ones lower case. See ToUpper.",
+  "letter upper case and the other ones lower case. See `ToUpper'.",
 };
 
 const char * const CASESEARCH_HELP[12] = {
@@ -158,7 +158,7 @@ const char * const CENTER_HELP[8] = {
   "centers N lines from the cursor position onwards. If N is not",
   "specified, it is assumed to be one. The lines are centered with spaces,",
   "relatively to the value of the right margin as set by the `RightMargin'",
-  "command. See RightMargin.",
+  "command. See `RightMargin'.",
 };
 
 const char * const CLEAR_HELP[7] = {
@@ -199,7 +199,7 @@ const char * const COPY_HELP[10] = {
   "copies the contents of the characters lying between the cursor and the",
   "mark into the clip specified by the optional numeric argument, the",
   "default clip being the current clip, which can be set with the",
-  "`ClipNumber' command (see ClipNumber). If the current mark was",
+  "`ClipNumber' command; see `ClipNumber'. If the current mark was",
   "vertical, the rectangle of characters defined by the cursor and the",
   "mark is copied instead.",
 };
@@ -257,9 +257,9 @@ const char * const DELETELINE_HELP[9] = {
   "Syntax: DeleteLine [N]",
   "Abbreviation: DL",
   "",
-  "deletes N lines starting from the current cursor position (putting the",
+  "deletes N lines starting from the current cursor position, putting the",
   "last one in the temporary buffer, from which it can be undeleted. See",
-  "UndelLine.) If the optional N argument is not specified, it is",
+  "`UndelLine'. If the optional N argument is not specified, it is",
   "assumed to be one. Note that this action is in no way inverse with",
   "respect to `InsertLine'.",
 };
@@ -300,7 +300,7 @@ const char * const ESCAPE_HELP[7] = {
   "",
   "toggles the menus on and off, or escapes from the input line. This",
   "command is mainly useful for reprogramming the menu activator, and it is",
-  "never registered while recording a macro. See Record.",
+  "never registered while recording a macro. `Record'.",
 };
 
 const char * const ESCAPETIME_HELP[16] = {
@@ -333,7 +333,7 @@ const char * const EXEC_HELP[13] = {
   "manually programmed macros.",
   "",
   "   Note that if the command you specify does not appear in `ne''s",
-  "internal tables, it is considered to be a macro name. See Macro.",
+  "internal tables, it is considered to be a macro name. See `Macro'.",
 };
 
 const char * const EXIT_HELP[6] = {
@@ -368,8 +368,8 @@ const char * const FIND_HELP[12] = {
   "searches for the given pattern. The cursor is positioned on the first",
   "occurrence of the pattern, or an error message is given. The direction",
   "and the case sensitivity of the search are established by the value of",
-  "the back search and case sensitive search flags. See See SearchBack",
-  "and See CaseSearch.",
+  "the back search and case sensitive search flags. See ",
+  "`SearchBack', and `CaseSearch'.",
   "",
   "   If the optional argument PATTERN is not specified, you can enter it",
   "on the input line, the default being the last pattern used.",
@@ -382,8 +382,8 @@ const char * const FINDREGEXP_HELP[12] = {
   "searches the current document for the given extended regular expression",
   ". The cursor is positioned on the first string matching the expression.",
   "The direction and the kind of search are established by the value of",
-  "the back search and case sensitive search flags. See See SearchBack",
-  "and See CaseSearch.",
+  "the back search and case sensitive search flags. See ",
+  "`SearchBack', and `CaseSearch'.",
   "",
   "   If the optional argument PATTERN is not specified, you can enter it",
   "on the input line, the default being the last pattern used.",
@@ -423,7 +423,7 @@ const char * const FLASH_HELP[6] = {
   "Abbreviation: FL",
   "",
   "acts as `Beep', but interchanging the words \"beep\" and \"flash\".  Same",
-  "comments apply. See Beep.",
+  "comments apply. See `Beep'.",
 };
 
 const char * const FREEFORM_HELP[18] = {
@@ -446,13 +446,19 @@ const char * const FREEFORM_HELP[18] = {
   "opinion). In this case, non-free-form.",
 };
 
-const char * const GOTOBOOKMARK_HELP[7] = {
-  "Syntax: GotoBookmark [N]",
+const char * const GOTOBOOKMARK_HELP[13] = {
+  "Syntax: GotoBookmark [N|-]",
   "Abbreviation: GBM",
   "",
-  "moves the cursor to the Nth bookmark. If the optional N argument is not",
-  "specified, it is assumed to be zero. There are ten bookmarks, numbered",
-  "from 0 to 9.",
+  "moves the cursor to the Nth or - automatic bookmark, assuming that",
+  "bookmark has been set; see `SetBookmark'. If the optional N",
+  "argument is not specified, it is assumed to be zero. When successful,",
+  "the `-' automatic bookmark is set to the position in the document from",
+  "which the command was issued, so that `GotoBookmark -' returns you to",
+  "the location from which you last issued a `GotoBookmark' command.",
+  "Subsequent repeated `GotoBookmark -' commands toggle you between the",
+  "two locations. Each document's valid bookmark designations are 0 to 9,",
+  "and the `-' automatic bookmark.",
 };
 
 const char * const GOTOCOLUMN_HELP[8] = {
@@ -481,11 +487,11 @@ const char * const GOTOMARK_HELP[9] = {
   "Syntax: GotoMark",
   "Abbreviation: GM",
   "",
-  "moves the cursor to the current mark, if it exists. See Mark.",
+  "moves the cursor to the current mark, if it exists. See `Mark'.",
   "",
   "   `GotoMark' is mainly useful if you forgot where you started marking.",
   "If you want to record a position in a file and jump to it later, you",
-  "may want to use a bookmark. See SetBookmark.",
+  "may want to use a bookmark. See `SetBookmark'.",
 };
 
 const char * const HELP_HELP[15] = {
@@ -502,7 +508,7 @@ const char * const HELP_HELP[15] = {
   "",
   "   Invocations of the `Help' command are never registered while",
   "recording macros so that you can safely access the help system while",
-  "recording. See Record.",
+  "recording. See `Record'.",
 };
 
 const char * const HEXCODE_HELP[7] = {
@@ -543,11 +549,11 @@ const char * const INSERTCHAR_HELP[20] = {
   "   Note that inserting a line feed (10) is completely different from",
   "inserting a line with `InsertLine'. `InsertChar 10' puts the control",
   "char `<Control>-J' in the text at the current cursor position.  See",
-  "InsertLine.",
+  "`InsertLine'.",
   "",
   "   Note also that `SaveMacro' converts `InsertChar' commands into a",
-  "possibly smaller number of `InsertString' commands.  (See",
-  "SaveMacro.) This makes macros easier to read and edit.",
+  "possibly smaller number of `InsertString' commands.  This makes macros",
+  "easier to read and edit. See `SaveMacro'.",
 };
 
 const char * const INSERTLINE_HELP[7] = {
@@ -569,8 +575,8 @@ const char * const INSERTSTRING_HELP[12] = {
   "indent, et cetera) are applied.",
   "",
   "   Note that `SaveMacro' converts `InsertChar' commands into a possibly",
-  "smaller number of `InsertString' commands.  (See SaveMacro.) This",
-  "makes macros easier to read and edit.",
+  "smaller number of `InsertString' commands.  This makes macros easier to",
+  "read and edit. See `SaveMacro'.",
 };
 
 const char * const LINEDOWN_HELP[6] = {
@@ -595,7 +601,7 @@ const char * const LOADAUTOPREFS_HELP[7] = {
   "",
   "loads the preferences file in `~/.ne' associated with the current",
   "document's file name extension. If the current file name has no",
-  "extension, the default preferences are loaded.  See AutoPrefs.",
+  "extension, the default preferences are loaded.  See `AutoPrefs'.",
 };
 
 const char * const LOADPREFS_HELP[16] = {
@@ -608,7 +614,7 @@ const char * const LOADPREFS_HELP[16] = {
   "   If the optional FILENAME argument is not specified, the file",
   "requester is opened, and you are prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.) If you escape from the file requester, you can",
+  "see `NoFileReq'.) If you escape from the file requester, you can",
   "input the file name on the command line.",
   "",
   "   Note that a preferences file is just a macro containing only option",
@@ -625,7 +631,7 @@ const char * const MACRO_HELP[31] = {
   "   If the optional FILENAME argument is not specified, the file",
   "requester is opened, and you are prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.)",
+  "see `NoFileReq'.)",
   "",
   "   If you escape from the file requester, you can input the file name",
   "on the command line.",
@@ -640,7 +646,7 @@ const char * const MACRO_HELP[31] = {
   "",
   "*Warning:* to improve (greatly) efficiency, the first time a macro is",
   "executed it is cached into a hash table and is kept _forever_ in memory",
-  "(unless the `UnloadMacros' command is issued; see UnloadMacros).",
+  "unless the `UnloadMacros' command is issued; see `UnloadMacros'.",
   "The next time a macro with the same file name is invoked, the cached",
   "list is searched for it before accessing the file using a case",
   "insensitive string comparison. That is, if you call `~/foobar/macro', a",
@@ -662,7 +668,7 @@ const char * const MARK_HELP[14] = {
   "position, respectively.  A capital `M' appears on the status bar, if",
   "the mark is active.",
   "",
-  "   See Record, for the reason the mark is implemented as a flag.",
+  "   See `Record', for the reason the mark is implemented as a flag.",
 };
 
 const char * const MARKVERT_HELP[10] = {
@@ -860,7 +866,7 @@ const char * const OPEN_HELP[18] = {
   "   If the optional FILENAME argument is not specified, the file",
   "requester is opened, and you are prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.)",
+  "see `NoFileReq'.)",
   "",
   "   If you escape from the file requester, you can input the file name",
   "on the command line, the default being the current document name, if",
@@ -874,13 +880,13 @@ const char * const OPENCLIP_HELP[14] = {
   "Syntax: OpenClip [FILENAME]",
   "Abbreviation: OC",
   "",
-  "loads the given file name as the current clip (just as if you copied",
-  "it; see Copy).",
+  "loads the given file name as the current clip, just as if you cut or",
+  "copied it from the current document; see `Copy'.",
   "",
   "   If the optional FILENAME argument is not specified, the file",
   "requester will open and you will be prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.)",
+  "see `NoFileReq'.)",
   "",
   "   If you escape from the file requester, you can enter the file name",
   "on the input line.",
@@ -890,13 +896,13 @@ const char * const OPENMACRO_HELP[14] = {
   "Syntax: OpenMacro [FILENAME]",
   "Abbreviation: OM",
   "",
-  "loads the given file name as the current macro (just as if you",
-  "`Record'ed it; see Record).",
+  "loads the given file name as the current macro just as if you",
+  "`Record'ed it; see `Record'.",
   "",
   "   If the optional FILENAME argument is not specified, the file",
   "requester is opened, and you are prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.)",
+  "see `NoFileReq'.)",
   "",
   "   If you escape from the file requester, you can input the file name",
   "on the command line.",
@@ -907,7 +913,7 @@ const char * const OPENNEW_HELP[6] = {
   "Abbreviation: ON",
   "",
   "is the same as `Open', but loads the file specified by the FILENAME",
-  "string into a new document. See Open.",
+  "string into a new document. See `Open'.",
 };
 
 const char * const PAGEDOWN_HELP[6] = {
@@ -933,7 +939,7 @@ const char * const PARAGRAPH_HELP[24] = {
   "reformats N paragraphs from the cursor position onwards. If N is not",
   "specified, it is assumed to be one. The paragraph are formatted",
   "relatively to the value of the right margin as set by the `RightMargin'",
-  "command. See RightMargin.",
+  "command. See `RightMargin'.",
   "",
   "   `ne''s notion of a paragraph includes the current non-blank line",
   "(regardless of its leading white space) and all subsequent non-blank",
@@ -958,7 +964,7 @@ const char * const PASTE_HELP[7] = {
   "",
   "pastes the contents of specified clip into the current document at the",
   "cursor position. If you don't specify the clip number, the current clip",
-  "is used (see ClipNumber for how to specify which clip is current).",
+  "is used; Specify which clip is current with `ClipNumber'.",
 };
 
 const char * const PASTEVERT_HELP[7] = {
@@ -993,11 +999,11 @@ const char * const POPPREFS_HELP[24] = {
   "",
   "pops N sets of preferences from the prefs stack (where they were placed",
   "previously by `PushPrefs') and applies those preferences to the current",
-  "buffer. See PushPrefs. If not specified, N defaults to one. Note",
-  "that the preferences stack is global, not buffer specific. Therefore",
-  "you could `PushPrefs' one buffer's preferences, switch buffers, then",
-  "`PopPrefs' those settings altering the preferences for the second",
-  "buffer. The maximum preferences stack depth is 32.",
+  "buffer. See `PushPrefs'. If not specified, N defaults to one.",
+  "Note that the preferences stack is global, not buffer specific.",
+  "Therefore you could `PushPrefs' one buffer's preferences, switch",
+  "buffers, then `PopPrefs' those settings altering the preferences for",
+  "the second buffer. The maximum preferences stack depth is 32.",
   "",
   "   `PushPrefs' and `PopPrefs' are useful in macros that require certain",
   "preferences to work properly.  A macro can `PushPrefs', change any",
@@ -1063,7 +1069,7 @@ const char * const PUSHPREFS_HELP[24] = {
   "",
   "pushes N copies of the user preferences onto a stack. If not specified,",
   "N defaults to one. Use the `PopPrefs' command to pop preferences off",
-  "the stack and restore the values. See PopPrefs. Note that the",
+  "the stack and restore the values. See `PopPrefs'. Note that the",
   "preferences stack is global, not buffer-specific, so you could",
   "`PushPrefs' one buffer's preferences, switch buffers, then `PopPrefs'",
   "those preferences, thereby altering the preferences for the second",
@@ -1098,7 +1104,7 @@ const char * const READONLY_HELP[13] = {
   "sets the read only flag. When this flag is true, no editing can be",
   "performed on the document (any such attempt produces an error message).",
   "This flag is automatically set whenever you open a file that you cannot",
-  "write to.  See Open.",
+  "write to.  See `Open'.",
   "",
   "   If you invoke `ReadOnly' with no arguments, it will toggle the flag.",
   "If you specify 0 or 1, the flag will be set to false or true,",
@@ -1112,8 +1118,8 @@ const char * const RECORD_HELP[21] = {
   "",
   "sets the recording state flag. When this flag becomes true, `ne' starts",
   "recording your actions in a new macro. When it becomes false, the macro",
-  "recording is stopped, and the macro can be played (see Play) or",
-  "saved (see SaveMacro).",
+  "recording is stopped, and the macro can be played or saved via ",
+  "`Play', or `SaveMacro'.",
   "",
   "   If you call invoke `Record' with no arguments, it will toggle the",
   "flag. If you specify 0 or 1, the flag will be set to false or true,",
@@ -1136,7 +1142,7 @@ const char * const REDO_HELP[8] = {
   "redoes the last N actions undone by `Undo' (as long as you don't take",
   "any actions that change the text between the `Undo' and `Redo'",
   "commands). If N is not specified, it is assumed to be one. You can only",
-  "`Redo' actions that have been `Undo'ne. See Undo.",
+  "`Redo' actions that have been `Undo'ne. See `Undo'.",
 };
 
 const char * const REFRESH_HELP[11] = {
@@ -1203,7 +1209,7 @@ const char * const REPLACE_HELP[46] = {
   "",
   "   * reversing the search direction (`Backward' or `Forward'); this",
   "     choice will also modify the value of the back search flag.  See",
-  "     SearchBack.",
+  "     `SearchBack'.",
   "",
   "",
   "   `Replace' is mainly useful for interactive editing. `ReplaceOnce',",
@@ -1212,20 +1218,20 @@ const char * const REPLACE_HELP[46] = {
   "   If no find string was ever specified, you can enter it on the input",
   "line.  If the optional argument STRING is not specified, you can enter",
   "it on the input line, the default being the last string used. When the",
-  "last search was a regular expression search (see FindRegExp), there",
-  "are some special features you can use in the replace string .",
+  "last search was a regular expression search, there are some special",
+  "features you can use in the replace string . See `FindRegExp'.",
   "",
   "   Note that normally a search starts just one character after the",
   "cursor.  However, when `Replace' is invoked, the search starts at the",
   "character just _under_ the cursor, so that you can safely `Find' a",
   "pattern and `Replace' it without having to move back.",
   "",
-  "*Warning:* when recording a macro (see Record), there is no trace",
-  "in the macro of your interaction with `ne' during the replacement",
+  "*Warning:* when recording a macro with `Record', there is no",
+  "trace in the macro of your interaction with `ne' during the replacement",
   "process. When the macro is played, you will again have to choose which",
   "actions to perform. If you want to apply automatic replacement of",
-  "strings for a certain number of times, you should look at See",
-  "ReplaceOnce, See ReplaceAll and See RepeatLast.",
+  "strings for a certain number of times, you should look at ",
+  "`ReplaceOnce', `ReplaceAll', and `RepeatLast'.",
 };
 
 const char * const REPLACEALL_HELP[12] = {
@@ -1239,7 +1245,7 @@ const char * const REPLACEALL_HELP[12] = {
   "the input line, the default being the last string used.",
   "",
   "   Note that `Undo' will restore _all_ the occurrences of the search",
-  "pattern replaced by `ReplaceAll'. See Undo.",
+  "pattern replaced by `ReplaceAll'. See `Undo'.",
 };
 
 const char * const REPLACEONCE_HELP[10] = {
@@ -1258,8 +1264,8 @@ const char * const RIGHTMARGIN_HELP[12] = {
   "Syntax: RightMargin [N]",
   "Abbreviation: RM",
   "",
-  "sets the right margin for all formatting operations, and for `WordWrap'",
-  "(see WordWrap).",
+  "sets the right margin for all formatting operations, and for `WordWrap'.",
+  "See `WordWrap'.",
   "",
   "   If the optional argument N is not specified, you can enter it on the",
   "input line, the default being the current value of the right margin.",
@@ -1268,7 +1274,7 @@ const char * const RIGHTMARGIN_HELP[12] = {
   "the current screen width as right margin.",
 };
 
-const char * const SAVE_HELP[12] = {
+const char * const SAVE_HELP[13] = {
   "Syntax: Save",
   "Abbreviation: S",
   "",
@@ -1276,7 +1282,8 @@ const char * const SAVE_HELP[12] = {
   "",
   "   If the current document is unnamed, the file requester will open and",
   "you will be prompted to select a file. (You can inhibit the file",
-  "requester opening by using the `NoFileReq' command; see NoFileReq.)",
+  "requester opening by using the `NoFileReq' command; see ",
+  "`NoFileReq'.)",
   "",
   "   If you escape from the file requester, you can input the file name",
   "on the command line.",
@@ -1291,7 +1298,7 @@ const char * const SAVEAS_HELP[14] = {
   "   If the optional FILENAME argument is not specified, the file",
   "requester will open and you will be prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.)",
+  "see `NoFileReq'.)",
   "",
   "   If you escape from the file requester, you can enter the file name",
   "on the input line, the default being the current document name, if",
@@ -1304,7 +1311,7 @@ const char * const SAVEAUTOPREFS_HELP[7] = {
   "",
   "saves the current preferences on the file in `~/.ne' associated with",
   "the current document's file name extension. If the current file name",
-  "has no extension, an error message is issued.  See AutoPrefs.",
+  "has no extension, an error message is issued.  See `AutoPrefs'.",
 };
 
 const char * const SAVECLIP_HELP[13] = {
@@ -1316,7 +1323,7 @@ const char * const SAVECLIP_HELP[13] = {
   "   If the optional FILENAME argument is not specified, the file",
   "requester will open and you will be prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.)",
+  "see `NoFileReq'.)",
   "",
   "   If you escape from the file requester, you can enter the file name",
   "on the input line.",
@@ -1339,7 +1346,7 @@ const char * const SAVEMACRO_HELP[20] = {
   "   If the optional FILENAME argument is not specified, the file",
   "requester is opened, and you are prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.)",
+  "see `NoFileReq'.)",
   "",
   "   If you escape from the file requester, you can input the file name",
   "on the command line.",
@@ -1348,8 +1355,8 @@ const char * const SAVEMACRO_HELP[20] = {
   "recorded. The macros can then be loaded as normal text files for",
   "further editing, if necessary. Note that `SaveMacro' converts",
   "`InsertChar' commands into a possibly smaller number of `InsertString'",
-  "commands. (See InsertChar, and See InsertString.)  This makes",
-  "macros easier to read and edit.",
+  "commands. This makes macros easier to read and edit. See ",
+  "`InsertChar', and `InsertString'.",
 };
 
 const char * const SAVEPREFS_HELP[11] = {
@@ -1361,7 +1368,7 @@ const char * const SAVEPREFS_HELP[11] = {
   "   If the optional FILENAME argument is not specified, the file",
   "requester is opened, and you are prompted to select a file. (You can",
   "inhibit the file requester opening by using the `NoFileReq' command;",
-  "see NoFileReq.) If you escape from the file requester, you can",
+  "see `NoFileReq'.) If you escape from the file requester, you can",
   "input the file name on the command line.",
 };
 
@@ -1378,7 +1385,7 @@ const char * const SEARCHBACK_HELP[14] = {
   "flag is true.",
   "",
   "   Note that this flag also can be set through interactions with the",
-  "`Replace' command. See Replace.",
+  "`Replace' command. See `Replace'.",
 };
 
 const char * const SELECTDOC_HELP[14] = {
@@ -1394,16 +1401,19 @@ const char * const SELECTDOC_HELP[14] = {
   "",
   "   `SelectDoc' is especially useful if you have a large number of",
   "documents open (say, more than 10). Otherwise, `NextDoc' and `PrevDoc'",
-  "should be enough. See NextDoc, and See PrevDoc.",
+  "should be enough. See `NextDoc', and `PrevDoc'.",
 };
 
-const char * const SETBOOKMARK_HELP[7] = {
-  "Syntax: SetBookmark [N]",
+const char * const SETBOOKMARK_HELP[10] = {
+  "Syntax: SetBookmark [N|-]",
   "Abbreviation: SBM",
   "",
   "sets the Nth bookmark to the current cursor position. If the optional N",
-  "argument is not specified, it is assumed to be zero. There are ten",
-  "bookmarks per document, numbered from 0 to 9.",
+  "argument is not specified, it is assumed to be zero. You can also unset",
+  "the `-' automatic bookmark, but it will be reset automatically to the",
+  "current position whenever a `GotoBookmark' command is issued. Each",
+  "document's valid bookmark designations are 0 to 9, and the `-' automatic",
+  "bookmark.",
 };
 
 const char * const STATUSBAR_HELP[19] = {
@@ -1482,9 +1492,9 @@ const char * const TOGGLESEOF_HELP[10] = {
   "moves the cursor to the start of document, if it is not already there;",
   "otherwise, moves it to the end of the document.",
   "",
-  "   This kind of toggling command (also see ToggleSEOL) is very",
-  "useful in order to gain some keystrokes on systems with very few keys.",
-  "See also See MoveSOF, and See MoveEOF.",
+  "   This kind of toggling command is very useful in order to gain some",
+  "keystrokes on systems with very few keys. See also `ToggleSEOL',",
+  "`MoveSOF', and `MoveEOF'.",
 };
 
 const char * const TOGGLESEOL_HELP[10] = {
@@ -1494,16 +1504,16 @@ const char * const TOGGLESEOL_HELP[10] = {
   "moves the cursor to the start of the current line, if it is not already",
   "there; otherwise, moves it to the end of the current line.",
   "",
-  "   This kind of toggling command (also see ToggleSEOF) is very",
-  "useful in order to gain some keystrokes on systems with very few keys.",
-  "See also See MoveSOL, and See MoveEOL.",
+  "   This kind of toggling command is very useful in order to gain some",
+  "keystrokes on systems with very few keys. See also `ToggleSEOF',",
+  "`MoveSOL', and `MoveEOL'.",
 };
 
 const char * const TOLOWER_HELP[5] = {
   "Syntax: ToLower [N]",
   "Abbreviation: TL",
   "",
-  "acts exactly like `ToUpper', but lowers the case. See ToUpper.",
+  "acts exactly like `ToUpper', but lowers the case. See `ToUpper'.",
 };
 
 const char * const TOUPPER_HELP[15] = {
@@ -1568,7 +1578,7 @@ const char * const UNDELLINE_HELP[15] = {
   "with clips.",
   "",
   "   Note that `UndelLine' works independently of the status of the undo",
-  "flag. See DoUndo.",
+  "flag. See `DoUndo'.",
 };
 
 const char * const UNDO_HELP[9] = {
@@ -1576,10 +1586,10 @@ const char * const UNDO_HELP[9] = {
   "Abbreviation: U",
   "",
   "undoes the last N actions. If N is not specified, it is assumed to be",
-  "one. After you undo a number of actions, you can `Redo' them (or some",
-  "of them; see Redo). However, if you take any new actions after",
+  "one. After you undo a number of actions, you can `Redo' all or some of",
+  "them; see `Redo'. However, if you take any new actions after",
   "having `Undo'ne some, you can no longer `Redo' those `Undo'ne actions.",
-  "See Redo.",
+  "See `Redo'.",
 };
 
 const char * const UNLOADMACROS_HELP[12] = {
@@ -1596,6 +1606,18 @@ const char * const UNLOADMACROS_HELP[12] = {
   "version available.",
 };
 
+const char * const UNSETBOOKMARK_HELP[10] = {
+  "Syntax: UnsetBookmark [N|-]",
+  "Abbreviation: UBM",
+  "",
+  "unsets the Nth bookmark, making it as if it had never been set; see",
+  "`SetBookmark'. If the optional N argument is not specified, it is",
+  "assumed to be zero. You can also unset the `-' automatic bookmark, but",
+  "it will be reset automatically to the current position whenever a",
+  "`GotoBookmark' command is issued. Each document's valid bookmark",
+  "designations are 0 to 9, and the  `-' automatic bookmark.",
+};
+
 const char * const UTF8_HELP[20] = {
   "Syntax: UTF8 [0|1]",
   "Abbreviation: U8",
@@ -1603,7 +1625,7 @@ const char * const UTF8_HELP[20] = {
   "sets the UTF-8 flag.  When this flag is true, `ne' considers the",
   "current buffer as UTF-8 coded.  Note that this flag is set",
   "automatically upon file loading (if possible) if you required automatic",
-  "detection. See UTF8Auto.",
+  "detection. See `UTF8Auto'.",
   "",
   "   If you invoke `UTF8' with no arguments, it will toggle the flag.  If",
   "you specify 0 or 1, the flag will be set to false or true,",
@@ -1618,15 +1640,16 @@ const char * const UTF8_HELP[20] = {
   "encoding, it also resets the undo buffer.",
 };
 
-const char * const UTF8AUTO_HELP[13] = {
+const char * const UTF8AUTO_HELP[14] = {
   "Syntax: UTF8Auto [0|1]",
   "Abbreviation: U8A",
   "",
   "sets the UTF-8 automatic-detection flag.  When this flag is true, `ne'",
   "will try to guess whether a file just loaded is UTF-8 encoded.",
   "Moreover, when a non US-ASCII character is inserted in a pure US-ASCII",
-  "buffer, ne will automatically switch to UTF-8. See UTF8. The flag",
-  "is true by default if `ne' detects UTF-8 I/O at startup. See UTF8IO.",
+  "buffer, ne will automatically switch to UTF-8. See `UTF8'. The",
+  "flag is true by default if `ne' detects UTF-8 I/O at startup. See ",
+  "`UTF8IO'.",
   "",
   "   If you invoke `UTF8Auto' with no arguments, it will toggle the flag.",
   "If you specify 0 or 1, the flag will be set to false or true,",
@@ -1672,8 +1695,8 @@ const char * const WORDWRAP_HELP[12] = {
   "Abbreviation: WW",
   "",
   "sets the word wrap flag. When this flag is true, `ne' will automatically",
-  "break lines of text longer than the current right margin (see",
-  "RightMargin) while you type them.",
+  "break lines of text longer than the current right margin while you type",
+  "them. See `RightMargin'.",
   "",
   "   If you invoke `WordWrap' with no arguments, it will toggle the flag.",
   "If you specify 0 or 1, the flag will be set to false or true,",
