@@ -1,7 +1,7 @@
 /* terminfo emulation through GNU termcap code.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2001 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -138,7 +138,7 @@ tparm() does it). Thus, instantiated strings longer than TPARAM_BUF_LEN will
 be copied in tparam_buffer and silently truncated. It should never happen
 with reasonable values for TPARAM_BUF_LEN, though. */
 
-char *tparm(const char *cap_string,...) {
+char *tparm(const char * const cap_string,...) {
 
 	static char tparam_buffer[TPARAM_BUF_LEN];
 
@@ -147,23 +147,23 @@ char *tparm(const char *cap_string,...) {
 	int i, arg[4];
 
 	va_start(ap, cap_string);
-	for(i=0; i<4; i++) arg[i] = va_arg(ap, int);
+	for(i = 0; i < 4; i++) arg[i] = va_arg(ap, int);
 	va_end(ap);
 
 	p = tparam(cap_string, tparam_buffer, TPARAM_BUF_LEN, arg[0], arg[1], arg[2], arg[3]);
 
 	if (p != tparam_buffer) {
-		memcpy(tparam_buffer, p, TPARAM_BUF_LEN-1);
+		memcpy(tparam_buffer, p, TPARAM_BUF_LEN - 1);
 		free(p);
 	}
 
-	return(tparam_buffer);
+	return tparam_buffer;
 }
 
 
 /* This is a real fake. We already know all the parameters. */
 
-int setupterm(const char *dummy1, int dunmmy2, int *dummy3) {
+int setupterm(const char * const dummy1, const int dunmmy2, const int * const dummy3) {
 
 	int l,c;
 	char *term_name = getenv("TERM"), *s;
@@ -257,7 +257,7 @@ int setupterm(const char *dummy1, int dunmmy2, int *dummy3) {
 	l = c = 0;
 	if (s = getenv("LINES")) l = atoi(s);
 	if (s = getenv("COLUMNS")) c = atoi(s);
-	if (l>0 && c>0) {
+	if (l > 0 && c > 0) {
 		ne_lines = l;
 		ne_columns = c;
 	}
@@ -290,8 +290,8 @@ int setupterm(const char *dummy1, int dunmmy2, int *dummy3) {
 	ne_scroll_forward = tgetstr("sf", NULL);
 	ne_scroll_reverse = tgetstr("sr", NULL);
 
-   ne_enter_delete_mode = tgetstr("dm", NULL);
-   ne_exit_delete_mode = tgetstr("ed", NULL);
+	ne_enter_delete_mode = tgetstr("dm", NULL);
+	ne_exit_delete_mode = tgetstr("ed", NULL);
 	ne_enter_insert_mode = tgetstr("im", NULL);
 	ne_exit_insert_mode = tgetstr("ei", NULL);
 
@@ -308,12 +308,12 @@ int setupterm(const char *dummy1, int dunmmy2, int *dummy3) {
 	ne_parm_delete_line = tgetstr("DL", NULL);
 
 	ne_insert_character = tgetstr("ic", NULL);
-   ne_parm_ich = tgetstr("IC", NULL);
+	ne_parm_ich = tgetstr("IC", NULL);
 
-   ne_insert_padding = tgetstr("ip", NULL);
+	ne_insert_padding = tgetstr("ip", NULL);
 
-   ne_delete_character = tgetstr("dc", NULL);
-   ne_parm_dch = tgetstr("DC", NULL);
+	ne_delete_character = tgetstr("dc", NULL);
+	ne_parm_dch = tgetstr("DC", NULL);
 
 	ne_move_insert_mode = tgetflag("mi");
 
