@@ -54,47 +54,59 @@ my ( %commands,
 
 foreach ( @infofiles )
   {
-    open INFO, $_ or die "Can't read command names.";
+    # Make texinfo refs and xrefs more readable.
+    # Refs and xrefs can span lines, so we have to
+    # deal single lines like this:
+    #    See *Note Key Bindings::.
+    # as well as multiple lines like this:
+    #    See *Note Key
+    #    Bindings::.
+    
+    open INFO, $_ or die "Can't read command names from '$_'.";
+    my @line = <INFO>;
+    close INFO;
+    my $line = join '', @line;
+    $line =~ s<\*note *(\s*)(.+?)::> <$1`$2'>gis;
 
-    while ( <INFO> )
+    my $state = 'searching';
+    my $command;
+    foreach ( split /\n/, $line )
       {
         chomp;
-        next unless ( m/^(Syntax: )`(([^ ]+).*)'\s*$/ );
-        my $command = uc $3;
-        $commands{$command}->{"cmd"}     = "$3";
-        $commands{$command}->{"text"}[0] = "$1$2";
-        
-        # print "---1 found $command\n";
-        
-        while ( <INFO> )
-          {
-            last if ( substr($_,0,1) eq chr(0x1f) );
-            chomp;
+        if ( $state eq 'searching' )
+            {
+              next unless ( m/^(Syntax: )`(([^ ]+).*)'\s*$/ );
+              $command = uc $3;
+              $commands{$command}->{"cmd"}     = "$3";
+              $commands{$command}->{"text"}[0] = "$1$2";
+              $state = 'building';
+              # print "---1 found $command\n";
+            }
+          elsif ( $state eq 'building' )
+            {
+              if ( substr($_,0,1) eq chr(0x1f) )
+                  {
+                    pop @{$commands{$command}->{"text"}}
+                      while ($commands{$command}->{"text"}[$#{$commands{$command}->{"text"}}] eq "");
+                      $state = 'searching';
+                      next;
+                  }
     
-            # print "---2 read \"$_\"\n";
+              # print "---2 read \"$_\"\n";
     
-            # make info hyperlinks more readable.
-            s/\*note\b/see/g;
-            s/\*Note\b/See/g;
-            s/:://g;
-            
-            if ( m/^(Abbreviation: )`(.+)'/ )
-                {
-                  $commands{$command}->{"abbr"} = "$2";
-                  push @{$commands{$command}->{"text"}}, "$1$2";
-                  # print "---3 pushing $1$2\n";
-                }
-              else
-                {
-                  push @{$commands{$command}->{"text"}}, $_;
-                  # print "---4 pushing $_\n";
-                }
-          }
-        pop @{$commands{$command}->{"text"}}
-            while ($commands{$command}->{"text"}[$#{$commands{$command}->{"text"}}] eq "");
+              if ( m/^(Abbreviation: )`(.+)'/ )
+                  {
+                    $commands{$command}->{"abbr"} = "$2";
+                    push @{$commands{$command}->{"text"}}, "$1$2";
+                    # print "---3 pushing $1$2\n";
+                  }
+                else
+                  {
+                    push @{$commands{$command}->{"text"}}, $_;
+                    # print "---4 pushing $_\n";
+                  }
+            }
       }
-    
-    close INFO;
   }
 
 ############################################################################
