@@ -100,10 +100,10 @@ char request_char(const buffer * const b, const char * const prompt, const char
 
 		switch(ic) {
 			case ALPHA:
-				return (char)up_case[(unsigned char)c];
+				return (char)localised_up_case[(unsigned char)c];
 
 			case RETURN:
-				return (char)up_case[(unsigned char)default_value];
+				return (char)localised_up_case[(unsigned char)default_value];
 
 			default:
 				break;
@@ -398,7 +398,7 @@ static void input_next_word(void) {
 
 	while(pos < len) {
 		const int c = get_char(&input_buffer[pos], encoding);
-		if (utf8isspace(c) || utf8ispunct(c)) space_skipped = TRUE;
+		if (ne_isspace(c, encoding) || ne_ispunct(c, encoding)) space_skipped = TRUE;
 		else if (space_skipped) break;
 		input_move_right(FALSE);
 	}
@@ -416,7 +416,7 @@ static void input_prev_word(void) {
 	while(pos > 0) {
 		input_move_left(FALSE);
 		c = get_char(&input_buffer[pos], encoding);
-		if (!(utf8isspace(c) || utf8ispunct(c))) word_skipped = TRUE;
+		if (!(ne_isspace(c, encoding) || ne_ispunct(c, encoding))) word_skipped = TRUE;
 		else if (word_skipped) {
 			input_move_right(FALSE);
 			break;
@@ -436,7 +436,7 @@ static void input_paste(void) {
 			return;
 		}
 
-		paste_len = strnlen(cd->cs->stream, cd->cs->len);
+		paste_len = strnlen_ne(cd->cs->stream, cd->cs->len);
 		if (len + paste_len > MAX_INPUT_LINE_LEN) paste_len = MAX_INPUT_LINE_LEN - len;
 		memmove(&input_buffer[pos + paste_len], &input_buffer[pos], len - pos + 1);
 		strncpy(&input_buffer[pos], cd->cs->stream, paste_len);
