@@ -624,7 +624,7 @@ void draw_status_bar(void) {
 
 	static char bar_buffer[MAX_BAR_BUFFER_SIZE];
 	static char flag_string[MAX_FLAG_STRING_SIZE];
-	static int x = -1, y = -1;
+	static int x = -1, y = -1, percent = -1;
 
 	char *p;
 	int len;
@@ -639,13 +639,16 @@ void draw_status_bar(void) {
 	if (!bar_gone && cur_buffer->opt.status_bar) {
 		/* This is the space occupied up to "L:", included. */
 		const int offset = cur_buffer->opt.fast_gui || !standout_ok ? 5: 3;
-		const int update_linecols = y != cur_buffer->cur_line || x != cur_buffer->win_x + cur_buffer->cur_x;
+		const int update_linecols = y != cur_buffer->cur_line || 
+		                            x != cur_buffer->win_x + cur_buffer->cur_x ||
+		                            percent != ((cur_buffer->cur_line + 1) * 100) / cur_buffer->num_lines;
 
 		if (!cur_buffer->opt.fast_gui && standout_ok) standout_on();
 		
 		x = cur_buffer->win_x + cur_buffer->cur_x;
 		y = cur_buffer->cur_line;
-		i = sprintf(bar_buffer, "%8d C:%8d %3d", y + 1, x + 1, ((y + 1) * 100) / cur_buffer->num_lines);
+		percent = ((cur_buffer->cur_line + 1) * 100) / cur_buffer->num_lines;
+		i = sprintf(bar_buffer, "%8d C:%8d %3d", y + 1, x + 1, percent);
 
 		if (update_linecols) {
 			move_cursor(ne_lines - 1, offset);
@@ -872,7 +875,7 @@ void get_menu_configuration(const char * menu_conf_name) {
 		if (menu_conf = malloc(strlen(prefs_dir) + strlen(menu_conf_name) + 1)) {
 			strcat(strcpy(menu_conf, prefs_dir), menu_conf_name);
 
-			if ((cs = load_stream(NULL, menu_conf_name, FALSE)) || (cs = load_stream(NULL, menu_conf, FALSE))) {
+			if ((cs = load_stream(NULL, menu_conf_name, FALSE, FALSE)) || (cs = load_stream(NULL, menu_conf, FALSE, FALSE))) {
 
 				for(pass = 0; pass < 2; pass++) {
 
@@ -984,7 +987,7 @@ void get_key_bindings(const char * key_bindings_name) {
 		if (key_bindings = malloc(strlen(prefs_dir) + strlen(key_bindings_name) + 1)) {
 			strcat(strcpy(key_bindings, prefs_dir), key_bindings_name);
 
-			if ((cs = load_stream(NULL, key_bindings_name, FALSE)) || (cs = load_stream(NULL, key_bindings, FALSE))) {
+			if ((cs = load_stream(NULL, key_bindings_name, FALSE, FALSE)) || (cs = load_stream(NULL, key_bindings, FALSE, FALSE))) {
 
 				p = cs->stream;
 				line = 1;
