@@ -375,6 +375,9 @@ const char UNDO_ABBREV[] = "U";
 const char UNLOADMACROS_NAME[]   = "UnloadMacros";
 const char UNLOADMACROS_ABBREV[] = "UM";
 
+const char UNSETBOOKMARK_NAME[]   = "UnsetBookmark";
+const char UNSETBOOKMARK_ABBREV[] = "UBM";
+
 const char UTF8_NAME[]   = "UTF8";
 const char UTF8_ABBREV[] = "U8";
 
@@ -427,6 +430,6 @@ const char * const command_names[ACTION_COUNT+1] = {
   SUSPEND_NAME,  SYSTEM_NAME,  TABSIZE_NAME,  THROUGH_NAME,
   TOGGLESEOF_NAME,  TOGGLESEOL_NAME,  TOLOWER_NAME,  TOUPPER_NAME,
   TURBO_NAME,  UNDELLINE_NAME,  UNDO_NAME,  UNLOADMACROS_NAME,
-  UTF8_NAME,  UTF8AUTO_NAME,  UTF8IO_NAME,  VERBOSEMACROS_NAME,
-  WORDWRAP_NAME,  NULL
+  UNSETBOOKMARK_NAME,  UTF8_NAME,  UTF8AUTO_NAME,  UTF8IO_NAME,
+  VERBOSEMACROS_NAME,  WORDWRAP_NAME,  NULL
 };
