@@ -369,6 +369,9 @@ extern const char UNDO_ABBREV[];
 extern const char UNLOADMACROS_NAME[];
 extern const char UNLOADMACROS_ABBREV[];
 
+extern const char UNSETBOOKMARK_NAME[];
+extern const char UNSETBOOKMARK_ABBREV[];
+
 extern const char UTF8_NAME[];
 extern const char UTF8_ABBREV[];
 
