@@ -69,6 +69,7 @@ char ARG_HELP[] = ABOUT_MSG "\n"
 						"--menus FILE  use this file for menu configuration.\n"
 						"--macro FILE  exec this macro after start.\n";
 
+
 /* The regular expression used to parse the locale. */
 
 #define LOCALE_REGEX "\\(UTF-?8\\)\\|\\(ISO-?8859-?\\)\\(1?[0-9]\\)"
@@ -138,13 +139,16 @@ int main(int argc, char **argv) {
 	if ( !(skiplist = calloc( argc, 1 )))  /* We need this many flags. */
 	  exit(1);                             /* This would be bad.       */
 
-	if ( locale = setlocale(LC_ALL, "") ) {
+	locale = setlocale(LC_ALL, "");
+	for(i = 0; i < 256; i++) localised_up_case[i] = toupper(i);
+
+	if (locale) {
 		struct re_pattern_buffer re_pb;
 		struct re_registers re_reg;
 		memset(&re_pb, 0, sizeof re_pb);
 		memset(&re_reg, 0, sizeof re_reg);
 
-		re_pb.translate = (char *)up_case;
+		re_pb.translate = (char *)localised_up_case;
 		re_compile_pattern(LOCALE_REGEX, strlen(LOCALE_REGEX), &re_pb);
 		if (re_search(&re_pb, locale, strlen(locale), 0, strlen(locale), &re_reg) >= 0) {
 			if (re_reg.start[1] >= 0) io_utf8 = TRUE;
