@@ -88,9 +88,9 @@ typedef enum {
 } encoding_type;
 
 
-/* The number of bookmarks per buffer. */
+/* The number of bookmarks per buffer. It comprises the automatic bookmark (0). */
 
-#define NUM_BOOKMARKS 10
+#define NUM_BOOKMARKS 11
 
 /* The name of the default preferences file name. */
 
@@ -391,6 +391,7 @@ typedef struct {
 		int pos;
 		int line;
 	} bookmark[NUM_BOOKMARKS];
+	int bookmark_mask;        /* bit N is set if bookmark[N] is set */
 
 	unsigned int
 
@@ -464,17 +465,14 @@ get_key_code()) its input class. */
 
 extern const input_class char_class[];
 
-/* This vector is a translation table for the regex library which maps
-lower case characters to upper case characters. It is also used elsewhere. */
-
-extern const unsigned char up_case[];
-
 /* This number defines the macro hash table size. This table can have
 conflicts. */
 
 #define MACRO_HASH_TABLE_SIZE (101)
 
-
+/* Upcasing vectors for the regex library. */
+extern unsigned char localised_up_case[];
+extern const unsigned char ascii_up_case[];
 
 #include "keycodes.h"
 #include "names.h"
