@@ -207,7 +207,7 @@ int save_prefs(buffer * const b, const char * const name) {
 		record_action(cs, CLIPNUMBER_A,    b->opt.cur_clip,       NULL, b->opt.verbose_macros);
 		record_action(cs, PRESERVECR_A,    b->opt.preserve_cr,    NULL, b->opt.verbose_macros);
 
-		error = save_stream(cs, name, b->is_CRLF);
+		error = save_stream(cs, name, b->is_CRLF, FALSE);
 
 		free_char_stream(cs);
 
@@ -233,7 +233,7 @@ int load_prefs(buffer * const b, const char * const name) {
 
 	b->exec_only_options = 1;
 
-	if (cs = load_stream(NULL, name, FALSE)) {
+	if (cs = load_stream(NULL, name, FALSE, FALSE)) {
 		error = play_macro(b, cs);
 		free_char_stream(cs);
 	}
