@@ -74,8 +74,8 @@ int paste_to_buffer(buffer *b, int n);
 int copy_vert_to_clip(buffer *b, int n, int cut);
 int erase_vert_block(buffer *b);
 int paste_vert_to_buffer(buffer *b, int n);
-int load_clip(int n, const char *name, int preserve_cr);
-int save_clip(int n, const char *name, int CRLF);
+int load_clip(int n, const char *name, int preserve_cr, int binary);
+int save_clip(int n, const char *name, int CRLF, int binary);
 
 /* command.c */
 void build_hash_table(void);
@@ -233,10 +233,10 @@ char_stream *realloc_char_stream(char_stream *cs, int size);
 int add_to_stream(char_stream *cs, const unsigned char *s, int len);
 char_stream *reset_stream(char_stream *cs);
 void set_stream_encoding(char_stream *cs, encoding_type source);
-char_stream *load_stream(char_stream *cs, const char *name, int preserve_cr);
-char_stream *load_stream_from_fh(char_stream *cs, int fh, int preserve_cr);
-int save_stream(const char_stream *cs, const char *name, int CRLF);
-int save_stream_to_fh(const char_stream *cs, int fh, int CRLF);
+char_stream *load_stream(char_stream *cs, const char *name, int preserve_cr, int binary);
+char_stream *load_stream_from_fh(char_stream *cs, int fh, int preserve_cr, int binary);
+int save_stream(const char_stream *cs, const char *name, int CRLF, int binary);
+int save_stream_to_fh(const char_stream *cs, int fh, int CRLF, int binary);
 
 int delete_from_stream(char_stream *cs, int p, int len);
 int insert_in_stream(char_stream *cs, const char *s, int p, int len);
@@ -247,7 +247,7 @@ const char *get_global_dir( void);
 const char *tilde_expand(const char *filename);
 const char *file_part(const char *pathname);
 char *str_dup(const char *s);
-int strnlen(const char *s, int n);
+int strnlen_ne(const char *s, int n);
 int strcmpp(const void *a, const void *b);
 void set_interactive_mode(void);
 void unset_interactive_mode(void);
@@ -286,11 +286,11 @@ void clear_end_of_line(int first_unused_hpos);
 void clear_to_eol(void);
 void clear_to_end(void);
 void clear_entire_screen(void);
-void output_chars(const char *string, int raw_len, int utf8);
+void output_chars(const unsigned char *string, int raw_len, int utf8);
 void output_string(const char *s, int utf8);
 void output_spaces(int n);
 void output_char(int c, int utf8);
-void insert_chars(const char *start, int raw_len, int utf8);
+void insert_chars(const unsigned char *start, int raw_len, int utf8);
 void insert_char(int c, int utf8);
 void delete_chars(int n);
 void ins_del_lines(int vpos, int n);
