@@ -206,10 +206,10 @@ int request_strings(const char * const * const local_entries, const int local_nu
 			case ALPHA:
 				if (n >= num_entries) n = num_entries - 1;
 
-				c = up_case[(unsigned char)c];
+				c = localised_up_case[(unsigned char)c];
 
 				for(i = 1; i < num_entries; i++)
-					if (up_case[(unsigned char)entries[(n + i) % num_entries][0]] == c) {
+					if (localised_up_case[(unsigned char)entries[(n + i) % num_entries][0]] == c) {
 
 						n = (n + i) % num_entries;
 
