@@ -1,7 +1,7 @@
 /* Signal handling setup and code.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2001 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -39,7 +39,7 @@ bad is happening, and then tries to autosave all the files currently in
 memory using auto_save(). If another signal arrives during the execution,
 we exit without any other delay. */
 
-static void fatal_code(int sig) {
+static void fatal_code(const int sig) {
 
 	fatal_error_code = sig;
 
@@ -87,12 +87,12 @@ void stop_ne(void) {
 static sigset_t signal_full_mask;
 
 
-/* This function diverts to fatal_code() the behaviour of all fatal signals.
-Moreover, signal_full_mask is filled with all the existing signals.
+/* Diverts to fatal_code() the behaviour of all fatal signals.  Moreover,
+   signal_full_mask is filled with all the existing signals.
 
-PORTABILITY PROBLEM: certain systems could have extra, non-POSIX signals whose
-trapping could be necessary. Feel free to add other signals to this list, but
-please leave SIGINT for the interrupt character. */
+   PORTABILITY PROBLEM: certain systems could have extra, non-POSIX signals
+   whose trapping could be necessary. Feel free to add other signals to this
+   list, but please leave SIGINT for the interrupt character. */
 
 void set_fatal_code(void) {
 
@@ -142,27 +142,25 @@ void release_signals(void) {
 
 
 
-/* This function handles SIGQUIT. It just sets the stop global variable to
-TRUE, so that the interested functions can check it, and restores itself as
-signal handler. */
+/* Handles SIGQUIT. It just sets the stop global variable to TRUE, so that the
+   interested functions can check it, and restores itself as signal handler. */
 
-void set_stop (int sig) {
+void set_stop (const int sig) {
 	signal(sig, SIG_IGN);
 	stop = TRUE;
 	signal(sig, set_stop);
 }
 
-/* This function handles SIGINT. It just restores itself as signal handler. */
+/* Handles SIGINT. It just restores itself as signal handler. */
 
-void handle_int (int sig) {
+void handle_int (const int sig) {
 	signal(sig, handle_int);
 }
 
-/* This function handles SIGWINCH, if present. It calls ttysize(). */
-
+/* Handles SIGWINCH, if present. It calls ttysize(). */
 
 #ifdef SIGWINCH
-void handle_winch (int sig) {
+void handle_winch (const int sig) {
 	signal(sig, SIG_IGN);
 	window_changed_size = ttysize();
 	signal(sig, handle_winch);
