@@ -150,7 +150,7 @@ int delete_from_stream(char_stream * const cs, const int pos, int len) {
 
 
 
-/* Reset a character stream. If cs is NULL, an empty character stream is
+/* Resets a character stream. If cs is NULL, an empty character stream is
 	returned. If it is non-NULL, everything inside it is freed. The stream
 	memory is deallocated, unless its size is smaller or equal to
 	2*CHAR_STREAM_SIZE_INC (so that we won't continously allocate and deallocate
@@ -185,9 +185,10 @@ void set_stream_encoding(char_stream * const cs, const encoding_type source) {
 
 /* These two functions load a stream in memory. Carriage returns and line feeds
 	are converted to NULLs. You can pass NULL for cs, and a char stream will be
-	allocated for you. If preserve_cr is TRUE, CRs are preserved. */
+	allocated for you. If preserve_cr is TRUE, CRs are preserved. If binary 
+   is true, the stream is filled exactly with the file content. */
 
-char_stream *load_stream(char_stream * cs, const char *name, const int preserve_cr) {
+char_stream *load_stream(char_stream * cs, const char *name, const int preserve_cr, const int binary) {
 
 	int fh;
 
@@ -199,13 +200,13 @@ char_stream *load_stream(char_stream * cs, const char *name, const int preserve_
 
 	if (is_migrated(name) || is_directory(name)) return NULL;
 
-	cs = load_stream_from_fh(cs, fh = open(name, READ_FLAGS), preserve_cr);
+	cs = load_stream_from_fh(cs, fh = open(name, READ_FLAGS), preserve_cr, binary);
 	if (fh >= 0) close(fh);
 
 	return cs;
 }
 
-char_stream *load_stream_from_fh(char_stream *cs, const int fh, const int preserve_cr) {
+char_stream *load_stream_from_fh(char_stream *cs, const int fh, const int preserve_cr, const int binary) {
 
 	int i, j, len;
 	char terminators[] = { 0x0d, 0x0a };
@@ -224,11 +225,17 @@ char_stream *load_stream_from_fh(char_stream *cs, const int fh, const int preser
 
 	if (!(cs = realloc_char_stream(cs, len))) return NULL;
 
-	if (read(fh, cs->stream, len)<len) {
+	if (read(fh, cs->stream, len) < len) {
 		free_char_stream(cs);
 		return NULL;
 	}
 
+	if (binary) {
+		cs->len = len;
+		assert_char_stream(cs);
+		return cs;
+	}
+
 	for(i = j = 0; i < len; i++, j++) {
 		if (i < len - 1 && !preserve_cr && cs->stream[i] == '\r' && cs->stream[i + 1] == '\n') i++;
 		cs->stream[j] = cs->stream[i];
@@ -248,10 +255,10 @@ char_stream *load_stream_from_fh(char_stream *cs, const int fh, const int preser
 
 
 /* These two functions save a stream to file. NULLs are converted to line
-	feeds. If CRLF is TRUE, we save CR/LF pairs as line terminators. They return
-	an error code. */
+	feeds. If CRLF is TRUE, we save CR/LF pairs as line terminators. If binary 
+   is true, the stream is dump literally. We return an error code. */
 
-int save_stream(const char_stream *const cs, const char *name, const int CRLF) {
+int save_stream(const char_stream *const cs, const char *name, const int CRLF, const int binary) {
 
 	int fh, error;
 
@@ -267,7 +274,7 @@ int save_stream(const char_stream *const cs, const char *name, const int CRLF) {
 	if ( is_directory(name) ) return  FILE_IS_DIRECTORY ;
 
 	if ((fh = open(name, WRITE_FLAGS, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH))>=0) {
-		error = save_stream_to_fh(cs, fh, CRLF);
+		error = save_stream_to_fh(cs, fh, CRLF, binary);
 		close(fh);
 		return error;
 	}
@@ -276,7 +283,7 @@ int save_stream(const char_stream *const cs, const char *name, const int CRLF) {
 }
 
 
-int save_stream_to_fh(const char_stream *const cs, const int fh, const int CRLF) {
+int save_stream_to_fh(const char_stream *const cs, const int fh, const int CRLF, const int binary) {
 
 	int pos = 0, len;
 
@@ -284,8 +291,13 @@ int save_stream_to_fh(const char_stream *const cs, const int fh, const int CRLF)
 
 	assert_char_stream(cs);
 
+	if (binary) {
+		if (write(fh, cs->stream, cs->len) < cs->len) return ERROR_WHILE_WRITING;
+		return OK;
+	}
+
 	while(pos < cs->len) {
-		len = strnlen(cs->stream + pos, cs->len - pos);
+		len = strnlen_ne(cs->stream + pos, cs->len - pos);
 
 		if (write(fh, cs->stream + pos, len) < len) return ERROR_WHILE_WRITING;
 
@@ -297,6 +309,6 @@ int save_stream_to_fh(const char_stream *const cs, const int fh, const int CRLF)
 		pos += len + 1;
 	}
 
-	return 0;
+	return OK;
 }
 
