@@ -233,7 +233,7 @@ char *str_dup(const char * const s) {
 /* Tries to compute the length as a string of the given pointer,
 	but stops after n characters (returning n). */
 
-int strnlen(const char *s, int n) {
+int strnlen_ne(const char *s, int n) {
 	const char * const p = s;
 	while(n-- != 0) if (!*(s++)) return s - p - 1;
 	return s - p;
@@ -561,3 +561,25 @@ int get_string_width(const unsigned char * const s, const int len, const encodin
 	for(pos = 0; pos < len; pos = next_pos(s, pos, encoding)) width += get_char_width(s + pos, encoding);
 	return width;
 }
+
+/* Returns whether the given character is a punctutation character. This function is 
+	compiled differently depending on whether wide-character function support is inhibited. */
+
+int ne_ispunct(const int c, const int encoding) {
+#ifdef NOWCHAR
+	return encoding != ENC_UTF8 ? ispunct(c) : c < 0x80 ? ispunct(c) : 0;
+#else
+	return encoding != ENC_UTF8 ? ispunct(c) : iswpunct(c);
+#endif
+}
+
+/* Returns whether the given character is whitespace. This function is 
+	compiled differently depending on whether wide-character function support is inhibited. */
+
+int ne_isspace(const int c, const int encoding) {
+#ifdef NOWCHAR
+	return encoding != ENC_UTF8 ? isspace(c) : c < 0x80 ? isspace(c) : 0;
+#else
+	return encoding != ENC_UTF8 ? isspace(c) : iswspace(c);
+#endif
+}
