@@ -148,7 +148,7 @@ void reset_undo_buffer(undo_buffer * const ub) {
 	ub->last_stream =
 	ub->steps_size =
 	ub->streams_size = 0;
-	ub->last_save_step = -1;
+	ub->last_save_step = 0;
 	free(ub->streams);
 	free(ub->steps);
 	ub->streams = NULL;
