@@ -131,25 +131,3 @@ int utf8tolower(const int c) {
    return towlower(c);
 #endif
 }
-
-/* Returns whether the given character is a punctutation character. This function is 
-	compiled differently depending on whether wide-character function support is inhibited. */
-
-int utf8ispunct(const int c) {
-#ifdef NOWCHAR
-   return c < 0x80 ? ispunct(c) : 0;
-#else
-   return iswpunct(c);
-#endif
-}
-
-/* Returns whether the given character is whitespace. This function is 
-	compiled differently depending on whether wide-character function support is inhibited. */
-
-int utf8isspace(const int c) {
-#ifdef NOWCHAR
-   return c < 0x80 ? isspace(c) : 0;
-#else
-   return iswspace(c);
-#endif
-}
