@@ -27,8 +27,6 @@ int utf8seqlen(int c);
 int utf8str(int c, unsigned char *  s);
 int utf8tolower(int c);
 int utf8toupper(int c);
-int utf8isspace(int c);
-int utf8ispunct(int c);
 
 /* Computes the length of an UTF-8 sequence, given the first byte. If the byte
 	is not a legal sequence start, this function returns -1. */
@@ -43,8 +41,6 @@ int utf8ispunct(int c);
 
 #ifdef NOWCHAR
 #define wcwidth(x) (1)
-#define towupper asciitoupper
-#define towlower asciitolower
 #else
 #include <wchar.h>
 #endif
